function CrownVicLXvehicle::onDriverEnter(%this, %veh)
{	
	//onDriverEnter and onDriverLeave both are called many times (up to 14) for some reason.
	//The hasDriver variable makes it so these things are done only one time each.
	if(!%veh.hasDriver)
	{
		%veh.hasDriver = 1;
		
		%this.headlights(%veh, "restore");
		
		%this.SpeedCheck(%veh);

		%veh.hidenode(speedo0);
		%veh.speedoSpeed = 1;
	}
}

function CrownVicLXvehicle::onDriverLeave(%this, %veh)
{		
	if(%veh.hasDriver)
	{
		%veh.hasDriver = 0;

		%veh.braking = 0;
		%veh.setNodeColor(brakeR1, %veh.BrakeColor2);
		%veh.setNodeColor(brakeL1, %veh.BrakeColor2);
		%veh.unhidenode(brakeC0);
		%veh.hidenode(brakeC1);
		
		%veh.unhideNode(reverseR0);
		%veh.unhideNode(reverseL0);
		%veh.hideNode(reverseR1);
		%veh.hidenode(reverseL1);
		%veh.reversing = 0;

		%this.headlights(%veh, "off");
		
		%veh.stopAudio(0);
		%veh.stopAudio(1);
		%veh.stopAudio(2);
		%veh.stopAudio(3);

		%veh.hidenode(speedo @ %veh.speedoSpeed);
		%veh.unhidenode(speedo0);
		%veh.speedoSpeed = 0;
		
		cancel(%veh.SpeedCheckSchedule);
	}
}

function CrownVicLXvehicle::onRemove(%this, %veh)
{
	%veh.removeMountedLightBot(4);
}

function CrownVicLXvehicle::SpeedCheck(%this, %veh)
{
	if(isEventPending(%veh.SpeedCheckSchedule))
	{
		return;
	}
	
	if(!isObject(%veh))
		return;
	
	%veh.speed = vectorDot(%veh.getVelocity(), %veh.getForwardVector());

	%tempSpeedoSpeed = mAbs(mFloor((%veh.speed / 5) + 0.5));

	if(%tempSpeedoSpeed != %veh.speedoSpeed)
	{
		if(%veh.headlightState > 0)
		{
			%veh.hidenode(speedo @ %veh.speedoSpeed @ g);
			%veh.unhidenode(speedo @ %tempSpeedoSpeed @ g);
		}
		else
		{
			%veh.hidenode(speedo @ %veh.speedoSpeed);
			%veh.unhidenode(speedo @ %tempSpeedoSpeed);
		}
		%veh.speedoSpeed = %tempSpeedoSpeed;
	}
	
	if(!%veh.reversing && %veh.speed <= -3)
	{
		%veh.hideNode(reverseR0);
		%veh.hideNode(reverseL0);
		%veh.unhideNode(reverseR1);
		%veh.unhidenode(reverseL1);
		%veh.reversing = 1;
	}
	else if(%veh.reversing && %veh.speed > -0.1)
	{
		%veh.unhideNode(reverseR0);
		%veh.unhideNode(reverseL0);
		%veh.hideNode(reverseR1);
		%veh.hidenode(reverseL1);
		%veh.reversing = 0;
	}
	
	%veh.SpeedCheckSchedule = %this.schedule(111, "SpeedCheck", %veh);
}

package CrownVicOnAddPackage
{
	function CrownVicLXvehicle::onAdd(%this, %veh)
	{
		Parent::onAdd(%this, %veh);
		
		%veh.spawnMountedLightBot(4);
		
		//%veh.headlightState = 2;
		
		%rearTire = strReplace(%this.defaultTire, "Tire", "RearTire");
		%veh.setWheelTire(2, %rearTire);
		%veh.setWheelTire(3, %rearTire);
		
		%veh.hidenode("ALL");

		%veh.unhidenode(speedo0);
		
		unhideNodeString(%veh, %this.paintableNodes SPC %this.interiorNodes SPC %this.unpaintableNodes);
		unhideNodeString(%veh, %this.windows["ext", "add"] SPC %this.windows["ext", "sub"] SPC %this.windows["int", "add"] SPC %this.windows["int", "sub"]);
		
		//The interior nodes lack color when the vehicle spawns, due to my parenting of setNodeColor, so color them individually.
		colorNodeString(%veh, %this.interiorNodes, getColorF(getWord(%this.interiorColor[1], 0)));
		//This default interior color is the same one which can be chosen by the command "/veh a"
		
		//Now, since we've interfered with setNodeColor, we need to recolor every node that isn't colored elsewhere.
		//Even though this doesn't change their appearance, if we DON'T do this, then players without shaders will see these nodes as all-white.
		//We need a list of the unpaintable nodes. Since this is only necessary at onAdd, we'll reassign the local variable %nodes.
		colorNodeString(%veh, %this.unpaintableNodes, "0 1 0 1");

		%veh.hideNode(dialsg);
		for(%i = 0; %i <= 13; %i++)
		{
			%veh.setNodeColor(speedo @ %i, "0 1 0 1");
			%veh.setNodeColor(speedo @ %i @ g, "0 1 0 1");
		}
		//If anything goes wrong, or textures are missing, and this appears where we don't want it, we want a nice, noticeable color, like neon green.
		//If someone complains of neon green, tell them to download textures, or get the most recent version of this vehicle.

		//Now, it's time to recolor some stuff that can't be customized later.
		//I do this so that things with lots of colors, like the headlights, brake lights, and windows...
		//...are visible to everyone, whether they download textures or not!
		//I already messed with setNodeColor in order to allow separate painting of the interior, so why not??
		
		//Paint the headlights. 
		colorNodeString(%veh, "headlightAR1 headlightAL1", "1 1 0.9 1");
		colorNodeString(%veh, "headlightBR1 headlightBL1", "1 0.66 0 1");
		colorNodeString(%veh, "reverseR0 reverseL0", "0.8 0.8 0.8 1");
		colorNodeString(%veh, "reverseR1 reverseL1", "1 1 0.9 1");
		
		//Now, I'm going to choose some colors for the brake lights, which will be switched around later.
		%veh.BrakeColor1 = "0.35 0 0 1";
		%veh.BrakeColor2 = "0.55 0 0 1";
		%veh.BrakeColor3 = "1.00 0.16 0 1";
		
		//Each of these nodes needs to start life with a color.
		colorNodeString(%veh, "brakeR0 brakeL0 brakeC0", %veh.brakeColor1);
		colorNodeString(%veh, "brakeR1 brakeL1", %veh.brakeColor2);
		%veh.setNodeColor("brakeC1",%veh.brakeColor3);	//ON version of center brakelight (this doesn't get changed later)

		//Now for the final step! There are a ridiculous number of nodes comprising the windows, and they need to be able to be colored differently.
		//Part of the advantage of using blank materials and applying color with a script is that they reflect the sun for those with shaders.
		//The fact that I use both additive and subtractive translucent materials means that you get surprisingly nice tinted windows!
		//All of this also means that there are 40 NODES FOR THE WINDOWS. WHY DID I DO THIS.
		
		colorNodeString(%veh, %this.windows["ext", "add"], %this.windowcolor["ext", "add"]);
		colorNodeString(%veh, %this.windows["ext", "sub"], %this.windowcolor["ext", "sub"]);
		colorNodeString(%veh, %this.windows["int", "add"], %this.windowcolor["int", "add"]);
		colorNodeString(%veh, %this.windows["int", "sub"], %this.windowcolor["int", "sub"]);
		
		//and the final detail...
		%veh.setNodeColor(headlightcover, "0.1 0.16 0.2 1");
	}
};
activatepackage(CrownVicOnAddPackage);